@@ -5,7 +5,7 @@ from .cache_utils import cpickle_cache
 from .list_utils import ListUtils
 from .process_notifier import process_notifier
 from .speed import Speed
-from .string_utils import String
+from .string_utils import StringUtils
 from .items_group_and_indexes import ItemsGroupAndIndexes
 from .item_increment_id_dict import ItemIncrementIdDict
 from .math_utils import MathUtils
@@ -15,7 +15,7 @@ from .extract_words import is_nltk_word, extract_words
 from .regexp_utils import regexp
 from .nlp import is_regular_word, jieba_parse
 from .lazy_data import ld
-from .unicode_utils import Unicode
+from .unicode_utils import UnicodeUtils
 from .entropy import calculate_entropy
 from .hash_utils import HashUtils
 from .itertools_utils import ItertoolsUtils
